@@ -22,6 +22,7 @@
 #include <QGLWidget>
 
 #include "molecule.h"
+//#include "fourxle.h"
 #ifndef MAXSELECT
 #define MAXSELECT 300001
 #endif
@@ -57,6 +58,15 @@ public:
 	 inRenameMode,//!< if true wee are in rename mode
 	 noWaitLabel,//!< if true wire mode after list initialization is not used to generate srceen shots.
          exporting;//!< for exporting bitmaps
+    QVector< QVector< float > > fVertexes;
+    QVector< QVector< float > > fNormals;
+    double lintrans;//!<degree of thansparency for the maps 0-1. 0 is transparent.
+    double linwidth;//!<linewidth of the meshes.
+
+    QColor fopc;//!< Fo positive color
+    QColor fomc;//!< Fo negative color
+    QColor dipc;//!< Fo-Fc positive color
+    QColor dimc;//!< Fo-Fc negative color
     struct labz{ 
     int x,y;
     QString l;
@@ -101,9 +111,8 @@ public:
     QStringList labs;//!< Labels for an envi-ronment list.
     Molecule *mol;//!< pointer to the Molecule object.
     int	murx;//!< non zero values lead to a rerendering of the display lists. 
-    static const int bas=1;//!< GL List base for atoms bonds unit cell.
-    static const int wirbas=11;//!< GL List base for wireframe bonds and atoms.
-    int foubas[37];//!< GL List base for the fourier maps.
+//    static const int bas=1;//!< GL List base for atoms bonds unit cell.
+//    static const int wirbas=11;//!< GL List base for wireframe bonds and atoms
     double L;//!< a scale factor.
     QAction *foact, //!< QAction toggling Fobs maps.
 	    *fofcact;//!< QAction toggling Fobs-Fcalc maps.
@@ -114,7 +123,8 @@ public:
                    *fillMap;//!< draw maps in filled style.
     QToolButton *rCenter;//!< resets the rotation center
     V3 altemitte;//!<rotation center position
-    void initLists();
+    V3 altcenter;
+//    void initLists();
     void zoom(double speed);
     bool isFO(){return drawFO;}//!< if Fo map is visible true is returned.
     bool isDF(){return drawDF;}//!< if Fo-Fc map is visible true is returned.
@@ -127,6 +137,8 @@ public:
     void moveY(double speed);
     void setupTexture();    
     void updateBondActions();
+    QList<int> lastClicked();
+    void pairing(QList<int> ima, QList<int> imb);
 signals:
     void no_hw_st();//!< we have no hard ware stereo sorry!
     void message(const QString &);//!< small text messages to the status bar.
@@ -157,7 +169,7 @@ public slots:
     void changeEnviRange();
     void changeTColor();
     void clearEnvi();
-    void clearLists();
+//    void clearLists();
     void connectSelection();
     void crosseye();
     void decFontSize();
@@ -203,6 +215,7 @@ public slots:
     void setReNaMo(bool b);
     void setRotationCenter();
     void setRotationCenter(int rz);
+    void setRotationCenter(V3 center);
     void setTube(bool b){
       //!sets tube mode to b
       tubes=b;
@@ -239,7 +252,7 @@ protected:
    void initializeGL();
    void resizeGL(int width, int height);
    void paintGL();
-#if (QT_VERSION >= 0x040600) && defined (Q_WS_MAC)
+#if (QT_VERSION >= 0x040600) && (defined (Q_WS_MAC) || defined(Q_OS_MAC))
    bool event(QEvent *event);
 #endif
    void mousePressEvent(QMouseEvent *event);
@@ -248,28 +261,24 @@ protected:
    void wheelEvent(QWheelEvent *event);
 private:
   QWidget *chparent; 
-  GLuint ppp,pp,p;     
-#if (QT_VERSION >= 0x040600) && defined (Q_WS_MAC)
+  int ppp,pp,p;//there is no need this should longer GLuint 26.02.2020
+#if (QT_VERSION >= 0x040600) && (defined (Q_WS_MAC) || defined(Q_OS_MAC))
         bool gestureEvent(QGestureEvent *event);
         void pinchTriggered(QPinchGesture*);
         void swipeTriggered(QSwipeGesture*);
 #endif
         bool mouseOverInteraction,atomsClickable,tubes,bggradient;
-	bool drawAx,drawUc,drawAt,drawADP,drawBo,drawLa,drawHb,drawFO,drawDF,
-	    // warfaul,
-	     warLabel;
+        bool drawAx,drawUc,drawAt,drawADP,drawBo,drawLa,drawHb,drawFO,drawDF, warLabel;
         int imFokus,afok;
-	void draw();
-        //void highFocus();
-	GLuint selectBuf[MAXSELECT];
-	GLfloat feedBuf[3000];
+        void draw();
+        Connection apair;
         GLint vp[4];
-	int hideReason; 
+        int hideReason;
         double qcutoff,pickradius;
-	int frid;
+        int frid;
         int withsymm;
         QPoint lastPos;
-    QStringList resis();
+        QStringList resis();
 };
 
 #endif // CHGL_H
