@@ -196,6 +196,88 @@ void CodeEditor::resizeEvent(QResizeEvent *e){
   e->accept();
 }
 
+void CodeEditor::expandGreaterThan(){//!< some SHELXL re- or constrainst use > to specify a range of atoms this is a problem for sorting atoms
+    QTextDocument *document = this->document();
+    for (int i=0; i<blocks.size(); i++){
+        if (blocks.at(i).startsWith("REM",Qt::CaseInsensitive)) continue;
+        if (blocks.at(i).contains('>')){
+            int comRN=-1,comPart=9999;
+            QString comRL="";
+            QString orig=blocks.at(i);
+            QStringList tokens=orig.split(QRegExp("\\s+"));
+            int da=tokens.indexOf(">");
+            QRegExp toReplace=QRegExp(QString("%1\\s+>\\s+%2").arg(tokens.at(da-1)).arg(tokens.at(da+1)));
+            QString with="";
+            if (tokens.at(0).contains("_")){
+                QString spec = tokens.at(0).section('_',1,1);
+                if (spec.contains(QRegExp("^[0-9]+$"))) comRN=spec.toInt();
+                else if (spec.contains(QRegExp("^[A-Z]"))) comRL=spec;
+                else if (spec.contains(QRegExp("^[a-z]$"))) comPart=spec.toInt(0,36)-9;
+            }
+            bool on=false;
+            //printf("%d %d \n",comRN,comPart);
+            for (int j=0; j< chgl->mol->asymm.size(); j++){
+                if (chgl->mol->asymm.at(j).an<1)continue;
+                QString s=chgl->mol->asymm.at(j).Label.section(QString::fromUtf8("_"),0,0);
+                if ((comRN>0)&&(chgl->mol->asymm.at(j).resiNr!=comRN))continue;
+                if ((comPart!=9999)&&((chgl->mol->asymm.at(j).part!=comPart)||(chgl->mol->asymm.at(j).part!=(25-comPart)))) continue;
+                if ((!comRL.isEmpty())&&(chgl->mol->asymm.at(j).ResiClass!=comRL))continue;
+                if (s==tokens.at(da-1)) on=true;
+                if (on) if (!with.contains(s+" ")){
+                    with.append(QString("%1 ").arg(s));
+                    if (with.section('=',-1,-1).length()>60) with.append(" = \n ");
+                }
+                if (s==tokens.at(da+1)) on=false;
+            }
+            //DSRGui::textWrap(buffer)
+            //qDebug()<<orig<<toReplace.pattern()<<with;
+            QTextCursor cursor = textCursor();
+            cursor.movePosition(QTextCursor::Start);
+            cursor = document->find(orig,cursor);
+            cursor.movePosition(QTextCursor::StartOfLine,QTextCursor::MoveAnchor);
+            cursor =document->find(toReplace);
+            cursor.insertText(with);
+        }
+        if (blocks.at(i).contains('<')){
+            int comRN=-1,comPart=9999;
+            QString comRL="";
+            QString orig=blocks.at(i);
+            QStringList tokens=orig.split(QRegExp("\\s+"));
+            int da=tokens.indexOf("<");
+            QRegExp toReplace=QRegExp(QString("%1\\s+<\\s+%2").arg(tokens.at(da-1)).arg(tokens.at(da+1)));
+            QString with="";
+            if (tokens.at(0).contains("_")){
+                QString spec = tokens.at(0).section('_',1,1);
+                if (spec.contains(QRegExp("^[0-9]+$"))) comRN=spec.toInt();
+                else if (spec.contains(QRegExp("^[A-Z]"))) comRL=spec;
+                else if (spec.contains(QRegExp("^[a-z]$"))) comPart=spec.toInt(0,36)-9;
+            }
+            bool on=false;
+            for (int j=chgl->mol->asymm.size()-1; j>=0; j--){
+                if (chgl->mol->asymm.at(j).an<1)continue;
+                QString s=chgl->mol->asymm.at(j).Label.section(QString::fromUtf8("_"),0,0);
+                if ((comRN>0)&&(chgl->mol->asymm.at(j).resiNr!=comRN))continue;
+                if ((comPart!=9999)&&((chgl->mol->asymm.at(j).part!=comPart)||(chgl->mol->asymm.at(j).part!=(25-comPart)))) continue;
+                if ((!comRL.isEmpty())&&(chgl->mol->asymm.at(j).ResiClass!=comRL))continue;
+                if (s==tokens.at(da-1)) on=true;
+                if (on) if (!with.contains(s+" ")) {
+                    with.append(QString("%1 ").arg(s));
+                    if (with.section('=',-1,-1).length()>60) with.append(" = \n ");
+                }
+                if (s==tokens.at(da+1)) on=false;
+            }
+            //DSRGui::textWrap(buffer)
+            //qDebug()<<orig<<toReplace.pattern()<<with;
+            QTextCursor cursor = textCursor();
+            cursor.movePosition(QTextCursor::Start);
+            cursor = document->find(orig,cursor);
+            cursor.movePosition(QTextCursor::StartOfLine,QTextCursor::MoveAnchor);
+            cursor =document->find(toReplace);
+            cursor.insertText(with);
+        }
+    }
+}
+
 QString CodeEditor::selectedRestraintsAtoms(QString buffer, QList<MyAtom> selected, QString resiSpec, bool exclude_H){
   //! Assembles the selected atom names to parameters for the specific restraint.
   for (QList<MyAtom>::iterator atom = selected.begin(); atom != selected.end(); atom++) {
@@ -835,8 +917,8 @@ void CodeEditor::sortAtoms(){
   const QString sicher = toPlainText();
   //find atomranges
   if (sicher.contains(QRegExp("[<>]"))){
-    QStringList ranges;
-    QStringList lines = sicher.split('\n');
+    //QStringList ranges;
+    /*QStringList lines = sicher.split('\n');
     for (int i=0; (i<lines.size()); i++){
       if (lines.at(i).startsWith(' ')) continue;
       if (lines.at(i).startsWith("REM",Qt::CaseInsensitive)) continue;
@@ -844,12 +926,13 @@ void CodeEditor::sortAtoms(){
       if (lines.at(i).contains(QRegExp("[<>]"))) ranges.append(QString("LINE %1: %2")
           .arg(i+1)
           .arg(lines.at(i)));
-    }
-    if (!ranges.isEmpty()){
+    }*/
+    expandGreaterThan();
+    /*if (!ranges.isEmpty()){
       QMessageBox::information(0,"information",QString("<h3>Atom ranges detected! %1 "
             " can not sort here without destroying functionality of the file.</h3 <pre>%2 </pre>").arg(PROGRAM_NAME).arg(ranges.join("\n")));
       return;
-    }
+    }*/
   }
   QMap<long double,MyAtom> atomSortMap;
 
@@ -931,11 +1014,11 @@ void CodeEditor::sortAtoms(){
   QTextDocument *document = this->document();
   QTextCursor cursor = textCursor();
   wholeLine->setChecked(false);
-  replace->setText("REM PART ");
-  searchLE->setText("^part ");
+  replace->setText("");
+  searchLE->setText("^part.*$");
   replaceAll();
-  replace->setText("REM RESI ");
-  searchLE->setText("^resi ");
+  replace->setText("");
+  searchLE->setText("^resi.*$");
   replaceAll();
   cursor.beginEditBlock();
   cursor.movePosition(QTextCursor::Start);
