@@ -17,12 +17,12 @@
  **
  ****************************************************************************/
 #include "eacDlg.h"
-#if defined (Q_WS_MAC)
-#include <OpenGL/glu.h>
-//#include <glu.h>
-#else
-#include <GL/glu.h>
-#endif
+//#if defined (Q_WS_MAC) || defined (Q_OS_MAC)
+//#include <OpenGL/glu.h>
+// //#include <glu.h>
+//#else
+//#include <GL/glu.h>
+//#endif
 #include "itsme.h"
 #ifndef GL_MULTISAMPLE
 #define GL_MULTISAMPLE  0x809D
@@ -295,8 +295,8 @@ void EacGLW::initializeGL(){
   glAlphaFunc ( GL_GREATER, 0.01f ) ;
   //glEnable(GL_ALPHA_TEST);
   glBlendFunc ( GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA ) ;
-  const GLfloat  OBJ_SPE[]   = { 1.0, 1.0, 1.0, 1.0 };  
-  const GLfloat  OBJ_SHIN    = 127.0;                   
+  const GLfloat  OBJ_SPE[]   = { 1.0f, 1.0f, 1.0f, 1.0f };  
+  const GLfloat  OBJ_SHIN    = 127.0f;                   
   glMaterialfv( GL_FRONT_AND_BACK, GL_SPECULAR,             OBJ_SPE  );
   glEnable     ( GL_COLOR_MATERIAL ) ;
   glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE ) ;    
@@ -306,7 +306,7 @@ void EacGLW::initializeGL(){
   glClearColor(0.4f,0.4f,0.4f,1.0f);
   glEnable(GL_DEPTH_TEST );
   glDepthFunc(GL_LEQUAL);
-  gluLookAt(0.0, 200, 50 ,   0.0, 0.0, 0.0,   0.0, -100, 400 );
+  gluLookAt_(0.0, 200, 50 ,   0.0, 0.0, 0.0,   0.0, -100, 400 );
   glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);
   saveProgram=mol->g_Program;
   mol->g_Program=new QGLShaderProgram(context(),this);
@@ -318,7 +318,7 @@ void EacGLW::resizeGL(int width, int height){
   glGetIntegerv(GL_VIEWPORT, vp);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
-  gluPerspective( 29.0, (double)width/height, 5.0, 8000.0 );
+  gluPerspective_( 29.0, (double)width/height, 5.0, 8000.0 );
 }
 
 void EacGLW::paintGL(){
@@ -328,7 +328,7 @@ void EacGLW::paintGL(){
   glGetIntegerv(GL_VIEWPORT, vp);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
-  gluPerspective( 29.0, (double)QGLWidget::width()/QGLWidget::height(), 5.0, 8000.0 );
+  gluPerspective_( 29.0, (double)QGLWidget::width()/QGLWidget::height(), 5.0, 8000.0 );
   glMatrixMode(GL_MODELVIEW);
   glPushMatrix();
   draw();
