@@ -30,13 +30,6 @@
 #include <QObject>
 #include <QCheckBox>
 
-#ifndef fmin
-#define fmin(x, y) (((x) < (y)) ? (x) : (y))
-#endif
-
-#ifndef fmax
-#define fmax(x, y) (((x) > (y)) ? (x) : (y))
-#endif
 //! Rec is a reflection type of a fcf 6 file.
 typedef struct {
 int  ih,//!< h
@@ -68,6 +61,7 @@ struct FNode {
     return Norm(n1.vertex-n2.vertex);
   }
 };
+
 //
 //!  FourXle is an QObject that loads a fcf 6 file and creates iso-surfaces in meshed style \inherit QObject 
 class FourXle:public QObject{
@@ -77,7 +71,8 @@ class FourXle:public QObject{
     float *datfo,//!<data pointer for the fobs map in real space
           *datfo_fc;//!<data pointer for the fobs-fcalc map in real space
     float f000;
-    FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, double resol=2.5, double wght=1.1);
+    float overridef000;
+    FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, QProgressBar *bar,double resol=2.5, double wght=1.1);
     /*!< @param mole_ pointer to the Molecule of ShelXle 
      *  @param chgl_ pointer to the ChGL widged of ShelXle
      *  @param toolView pointer to the View Toolbar of ShelXle
@@ -101,6 +96,7 @@ class FourXle:public QObject{
     QAction *mapcontrol;
     QCheckBox *ownfcf6;
     QString  fouName;
+    void drawMap(int faps);
     int maptrunc;
     double map_radius; //!< radius of the map in Angstrom around the rotaion center (used only in a mode of FourXle).
 
@@ -108,8 +104,6 @@ class FourXle:public QObject{
     bool loadMap(int NX, int NY, int NZ, float *dat);
     QDir resDir;
     QCheckBox *keepIso;//!<keeps the initial iso values good for idieal presentations
-    double lintrans,//!<degree of thansparency for the maps 0-1. 0 is transparent.
-           linwidth;//!<linewidth of the meshes.
     float sigma[3];//!<sigma values 
     float iso[3];//!<iso values
     //  double mInimum[2],mAximum[2];
@@ -121,13 +115,9 @@ class FourXle:public QObject{
 
     QCheckBox *doMaps;//!< do or notthing todo is the question
     Molecule *mole;//!< pointer to the Molecule object
-    QColor fopc,//!< Fo positive color
-           fomc,//!< Fo negative color
-           dipc,//!< Fo-Fc positive color
-           dimc;//!< Fo-Fc negative color
     ChGL *chgl;//!< pointer to the ChGL widget
     QString voxelstr;//!< a string to fix dimensions to desired values by comand line option '-voxel 92x92x92 '
-    void deleteLists();
+    //void deleteLists();
     void killmaps();
     void jnk();
     float sigmaFo();
@@ -141,8 +131,8 @@ class FourXle:public QObject{
     V3 dx,//!< vector in a direction for each map voxel
        dy,//!< vector in b direction for each map voxel
        dz;//!< vector in c direction for each map voxel
-    public slots:
-      void bewegt(V3 v);
+public slots:
+    void bewegt(V3 v);
     void inimap();
     void change_iso(int numsteps,int diff);
     void chglDestroyed();
@@ -160,9 +150,12 @@ class FourXle:public QObject{
     void colorDLGDIM();//!<Color Dialog for Fobs-Fcalc minus. Negative values of Fo-Fc map are drawn with a mesh in this color.
     void defaultColors();//!<Restores the default colors of the electron density maps (Fo+ blue Fo- yellow Fo-Fc+ green Fo-Fc- red).
     void openMapControl();//!< shows the Map Control dialog.
+    void updateLines();
+    void reportInfo();
 signals:
     void bigmessage(const QString &);//!< to comunicate with the informaton window
     void reloadRes();
+    void progress(int v);
 
   private:
     double C[15],D[9],sy[12][192],wave;
@@ -171,6 +164,7 @@ signals:
     inline int dex3(int x,int y,int z);
     int oldatomsize;
     int acnt;
+    QString info;
     V3 oc,dxc,dyc,dzc;
     V3  delDA[27];
 #ifdef FFTW3_H
@@ -190,19 +184,53 @@ signals:
     //          double minnor,maxnor;
     void gen_surface(bool neu,int imin=0, int imax=4);
     void CalcVertex( int ix, int iy, int iz);
-    V3 CalcNormalX( int ix, int iy, int iz );
-    V3 CalcNormalY( int ix, int iy, int iz );
-    V3 CalcNormalZ( int ix, int iy, int iz );
-    int IndexSelected( FNode& node0, FNode& node1, FNode& node2, FNode& node3 );
-    V3& VectorSelected( FNode& node0, FNode& node1, FNode& node2, FNode& node3 );
-    void MakeElement( int ix, int iy, int iz ,int s1, int s2);
-    void makeFaces(int n, FNode poly[] );
+//    V3 CalcNormalX( int ix, int iy, int iz );
+//    V3 CalcNormalY( int ix, int iy, int iz );
+//    V3 CalcNormalZ( int ix, int iy, int iz );
+    int IndexSelected( FNode& node0, FNode& node1, FNode& node2, FNode& node3);
+//    V3& VectorSelected( FNode& node0, FNode& node1, FNode& node2, FNode& node3);
+    void MakeElement( int ix, int iy, int iz ,int s1, int s2, int faps);
+    void makeFaces(int n, int faps, FNode poly[] );
 
     char titl[80];/*fcmax=0,f000=0,resmax=99999.0,*/
     void trimm(char s[]);
     void deletes(char *s, int count);
     int readHeader(const char *filename);
     void sorthkl(int nr, Rec r[]);
+
+    friend class GenMapWorker;
 };
 
+
+
+class GenMapWorker : public QThread{
+Q_OBJECT
+  public:
+  GenMapWorker(ChGL *chgl_,Molecule *mol_, FourXle *parent, bool neu_=true,int imin_=0, int imax_=4){
+    chgl = chgl_;
+    mole=mol_;
+    fxle = parent;// maybe I need it later?
+    neu=neu_;
+    imin=imin_;
+    imax=imax_;
+  }
+  ~GenMapWorker(){
+   //printf("destruct GenMapWorker\n");
+  }
+
+  void run() {
+    /* expensive or blocking operation  */
+    gen_surface(neu, imin,imax);
+  }
+  void gen_surface(bool neu,int imin=0, int imax=4);
+  ChGL *chgl;
+  FourXle *fxle;//parent
+  Molecule *mole;
+  bool neu;
+  int imin,imax;
+signals:
+  void progress(int v);
+};
+
+
 #endif
