@@ -127,6 +127,9 @@ void mh(QtMsgType type, const char *msg){
 #endif
 
 void printicon(){
+#if defined Q_WS_WIN  ||   defined Q_OS_WIN
+#define DEFINE_CONSOLEV2_PROPERTIES
+#endif
   QImage II=QImage(":/icons/SHELxLE.png" );
 //  QImage II=QPixmap(":/icons/cbh.png" ).toImage();
   int r, g, b, c216,gray,k=0;
@@ -142,17 +145,28 @@ void printicon(){
     c216 = 16 + 36 * r + 6 * g + b;
     gray =qGray(II.pixel(i,j))/11+232;
     gray= (int)(alpha*gray +(235*(1.0-alpha)));
+#if defined Q_WS_WIN  ||   defined Q_OS_WIN
+    wprintf(L"\x1b[48;5;%dm\x1b[38;5;%dm%c",c216,gray,x[k%8]);
+#else
     printf("\e[48;5;%dm\e[38;5;%dm%c",c216,gray,x[k%8]);
+#endif
     //printf("\e[48;5;%dm\e[38;5;%dm%c",gray,c216,x[k%8]);
     k++;
   }
+#if defined Q_WS_WIN  ||   defined Q_OS_WIN
+  wprintf(L"\x1b[0;0;0m\n");j++;
+#else
   printf("\e[0;0;0m\n");j++;
+#endif
   }
 
 
 }
 
-int main(int argv, char *args[]){
+int main(int argv, char *args[]){    
+  char *ENUS=setlocale(LC_ALL,"C");
+  if (!ENUS)ENUS=setlocale(LC_ALL,"en_US.UTF-8");
+  printf("%s\n",ENUS);
   QApplication app(argv, args);
   
   app.setOrganizationName("shelxle");
