@@ -22,6 +22,9 @@
 #ifndef fmin
 #define fmin(x, y) (((x) < (y)) ? (x) : (y))
 #endif
+#ifndef fmax
+#define fmax(x, y) (((x) > (y)) ? (x) : (y))
+#endif
 #if defined _MSC_VER &&  _MSC_VER == 1500
 #ifndef round 
 #define round(x) (x<0?ceil((x)-0.5):floor((x)+0.5))
@@ -32,12 +35,13 @@
 #include <QList>
 #include <QtOpenGL>
 #include <QGLShaderProgram>
-#if defined (Q_WS_MAC)
-#include <OpenGL/glu.h>
-//#include <glu.h>
-#else
-#include <GL/glu.h>
-#endif
+//#if defined (Q_WS_MAC) || defined(Q_OS_MAC)
+//#include <OpenGL/glu.h>
+// //#include <glu.h>
+//#else
+//#include <GL/glu.h>
+//#endif
+#include "glureplace.h"
 #include <QtCore>
 #ifndef M_PI
 #define	M_PI		3.14159265358979323846
@@ -149,7 +153,7 @@ inline double Distance( const V3& v1, const V3& v2 ) {
 }//!< The squared distance between two V3
 inline bool operator == (const V3& v1, const V3& v2 ) {
   //  return ((v1.x==v2.x)&&(v1.y==v2.y)&&(v1.z==v2.z));
-  return (Distance(v1,v2)<0.001);
+  return (Distance(v1,v2)<0.005);
 }
 inline V3& Normalize( V3 v ) {
   static V3 erg=V3(1,0,0);
@@ -1192,15 +1196,22 @@ struct SdmItem{
 };
 
 inline bool operator < (const SdmItem &a1, const SdmItem &a2){
-  double d1=a1.d;//a1.a2*99999+a1.d;
-  double d2=a2.d;//a2.a2*99999+a2.d;
-  return (d1<d2);
+  return (a1.d<a2.d);
+}
+
+struct Tripel{
+  int n[3];
+  V3 midcenter;
+};
+inline bool operator == (const Tripel& v1, const Tripel& v2 ) {
+  return ((v1.n[0]==v2.n[0])&&(v1.n[1]==v2.n[1])&&(v1.n[2]==v2.n[2]));
 }
 //!Knopf is a list of neighbors of an atom
 struct Knopf{
   //! neighbors is list of atom indices of neigbours of that atom
   QList<int> neighbors;
 };
+class Ring;
 /*! \brief Molecule is a crystallography and molecular structure object of shelXle. 
  *
  * It has routines to convert coordinates and 
@@ -1278,13 +1289,15 @@ class Molecule{
     QColor enviBondColor,//!< covalent color in ENVI
            enviHBColor,//!< hydrogen bond color in ENVI
            enviDefaultColor;//!< default color in ENVI
-    CEnvironment asymm,//!< atom list containing the asymertic unit 
-                 showatoms,//!< atom list containing all atoms to be drawn.
-                 selectedatoms,//!< atom list of selected atoms.
-                 duplicateAtoms,//!< atom list of identcal labeled atoms.
-                 legendAtoms;//!< Atoms in a key legend.
+    CEnvironment asymm;//!< atom list containing the asymertic unit
+    CEnvironment showatoms;//!< atom list containing all atoms to be drawn.
+    CEnvironment selectedatoms;//!< atom list of selected atoms.
+    CEnvironment duplicateAtoms;//!< atom list of identcal labeled atoms.
+    CEnvironment legendAtoms;//!< Atoms in a key legend.
     Connection showbonds;//!< list of visible bonds.
     Connection lbonds;//!< list of line bonds (for Q-Peaks)
+    CEnvironment fitatoms;//!<
+    Connection fitbonds;//!<
     QStringList usedSymmetry;//!< List of internal symmetry codes of symmetry operations curently applied.
     QString HumanSymmetry;//!< A human readable list of symmetry operations in use.
     QSettings *einstellung;//!< the QSetttings for ShelXle.
@@ -1292,6 +1305,7 @@ class Molecule{
     //
     //
     QStringList sdmcompleter();
+    QList<SdmItem> computeSDM(CEnvironment au);
     void atoms(CEnvironment atom,int proba=50);
     bool shaders_work;//!< can glsl shader run on this machine?
     bool program_in_use;//!< glsl program active 
@@ -1299,7 +1313,7 @@ class Molecule{
     void shaderAtoms(CEnvironment atom,int proba=50);//!< like void atoms(CEnvironment atom,int proba=50); but with shaders
     void pappe();//!< the inner walls of an ellipsoid (use ony with shaders and 'wall' uniform set)
     void bonds(Connection bond);
-    void dbond(Connection bond);
+    void dbond(Connection bond,int ccode=0);
     void lbond();
     QString h_bonds(Connection bond,CEnvironment atoms);
     void h_bonds2(Connection bond,CEnvironment atoms);
@@ -1348,10 +1362,14 @@ class Molecule{
     void triacontaeder(GLfloat r);
     void cube(GLfloat r);
     int maxmols(){return maxmol;}//!< returns the number of fragments (molecules)
+    void newstructure(){maxmol=0;}//!< new structure initialize maxmol to 0
     const QStringList thepse(){return PSE;}
     int pseSize(){return PSE.size();}
     Matrix u2b(Matrix u);//!< compute Bij values from Uij 
     Matrix b2u(Matrix u);//!< compute Uij values from Bij 
+    void extendChain(QList<Ring > &rings, QList<int> &currentChain, QList<QList<int> > &neighbors,QSet<int> &nogo);
+
+    void inventNewLabels(QList<int> &result);//!< lets see where it goes
   private:
     void neighborSort(Knopf &kn);
     bool checkExtensions();
@@ -1379,4 +1397,77 @@ class Molecule{
     int lodH;
     QStringList PSE;
 };
+
+class Ring{
+public:
+    bool complete;
+    bool done;
+    QList<Tripel> t;
+    QList<int> members;
+    V3 center;
+Ring(Tripel t1,Tripel t2){
+  complete=false;
+  done=false;
+  t.append(t1);
+  t.append(t2);
+  center = t1.midcenter + t2.midcenter;
+  members.append(t1.n[1]);
+  members.append(t1.n[0]);
+  members.append(t1.n[2]);
+  if (!members.contains(t2.n[1])) members.append(t2.n[1]);
+  if (!members.contains(t2.n[0])) members.append(t2.n[0]);
+  if (!members.contains(t2.n[2])) members.append(t2.n[2]);
+
+}
+~Ring(){
+  t.clear();
+  members.clear();
+}
+
+bool isComplete(){
+  if (complete) return complete;
+  complete = (members.size()==t.size());
+  if (complete) bringInOrder();
+  return complete;
+}
+
+V3 theCenter(){
+  return center*(1.0/t.size());
+}
+
+void bringInOrder(){
+  members.clear();
+  members.append(t.at(0).n[0]);
+  while (members.size()!=t.size()){
+    for (int i=0; i<t.size(); i++){
+      if ((members.last()==t.at(i).n[1])&&(!members.contains(t.at(i).n[0])))members.append(t.at(i).n[0]);
+      else if ((members.last()==t.at(i).n[2])&&(!members.contains(t.at(i).n[0])))members.append(t.at(i).n[0]);
+    }
+  }
+}
+
+void printRing(Molecule *mol){
+  QString str="+";
+  for (int i = 0; i < members.size(); i++){
+    str.append(mol->asymm.at(members.at(i)).Label);
+    str.append((i==members.size()-1)?"+\n+":"=");
+  }
+  int l=str.size()-4;
+  for (int i=0; i<l; i++) str.append("=");
+  str.append("+\n");
+  printf("%s",str.toStdString().c_str());
+  str.clear();
+}
+
+void addTripel(Tripel nt){
+  if (t.contains(nt)) return;
+  t.append(nt);
+  center += nt.midcenter;
+  if (!members.contains(nt.n[1])) members.append(nt.n[1]);
+  if (!members.contains(nt.n[0])) members.append(nt.n[0]);
+  if (!members.contains(nt.n[2])) members.append(nt.n[2]);
+  isComplete();
+}
+
+};
 #endif
