@@ -32,6 +32,9 @@
 #include "fourxle.h"
 #include "fcvsfo.h"
 #include "itsme.h"
+#ifndef nullptr 
+#define nullptr NULL
+#endif
 #ifndef fmin
 #define fmin(x, y) (((x) < (y)) ? (x) : (y))
 #endif
@@ -142,6 +145,10 @@ public:
   int getFvarCntr(int fvar);//!< returns the number of uses of a free variable.
   int firstAtomLine;
   
+signals:
+  void fileLoaded(void);
+  void pipeStatus(const QString& s);  //!<changes the statusbar text to s @param s text for the status bar
+  
 public slots:
   void qinitres();
   void about();//!<Shows the about dialog of ShelXle.
@@ -156,6 +163,7 @@ public slots:
   void addHnonplanarAminR1();
   void addMoreQPeaks();//!<Creates Q-Peaks from the Fo-Fc map.
   void adoptEditToolBar(bool b);//editToolbar is child of shxMW or the MainWindow
+  void aula();//!< Auto Labeling
   void autoHFix();//!<Automatically adds H atoms and AFIX instructions to the file uses the Fo-Fc map. 
   void brwsIcon();//!< Select an alternative icon for external program
   void changeFixes(int i);//!< Variable that should not be refined get a 10 added.
@@ -467,9 +475,6 @@ private:
   Calculator *calcmenu;
   DSRGui *dsr;
   //QString selectedRestraintsAtoms(QString buffer, QList<MyAtom> selected, QString resiSpec, bool exclude_H=false);
-  
-signals:
-  void fileLoaded(void);
 
 };
 #endif
